# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_SUBMIT_JOBS_METADATA = Metadata(
    id="d9fdcdcc044b4b6a583cb8d7681940ebbb389e10.boutiques",
    name="long_submit_jobs",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongSubmitJobsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_submit_jobs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def long_submit_jobs(
    qdec: InputPathType,
    cdir: str,
    bdir: str | None = None,
    ldir: str | None = None,
    scriptsdir: str | None = None,
    cross: bool = False,
    base: bool = False,
    long: bool = False,
    cflags: str | None = None,
    bflags: str | None = None,
    lflags: str | None = None,
    affine: bool = False,
    force: bool = False,
    simulate: bool = False,
    simfiles: bool = False,
    check: bool = False,
    pause: float | None = None,
    max_: float | None = None,
    queue_: str | None = None,
    cmem: float | None = None,
    bmem: float | None = None,
    lmem: float | None = None,
    cnodes: float | None = None,
    bnodes: float | None = None,
    lnodes: float | None = None,
    runner: Runner | None = None,
) -> LongSubmitJobsOutputs:
    """
    Submits longitudinal processing jobs to the NMR cluster (seychelles or
    launchpad).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec: QDEC table file specifying the subjects and time points.
        cdir: Directory for cross-sectional subjects (inherited by base and\
            long).
        bdir: Directory for base runs (default: inherit from cross).
        ldir: Directory for longitudinal runs (default: inherit from base).
        scriptsdir: Location to save submitted scripts (default:\
            <cdir,bdir,ldir>/scripts_submitted).
        cross: Process cross-sectional streams.
        base: Process base streams.
        long: Process longitudinal streams.
        cflags: Manual flags for cross processing (e.g., '-all -cw256').
        bflags: Manual flags for base processing (default: '-all').
        lflags: Manual flags for long processing (default: '-all').
        affine: Use affine registration for base.
        force: Force reprocessing of jobs even if marked as done.
        simulate: Simulate submission only, without executing.
        simfiles: Simulate command file creation only, without executing.
        check: Check if all longitudinal processing is complete.
        pause: Pause duration (in seconds) between submissions (default: 13).
        max_: Maximum number of jobs per user (default: 100).
        queue_: Queue to submit jobs.
        cmem: RAM (in GB) requested for cross (default: 7).
        bmem: RAM (in GB) requested for base (default: 7).
        lmem: RAM (in GB) requested for long (default: 7).
        cnodes: Number of nodes for cross runs (default: 1).
        bnodes: Number of nodes for base runs (default: 1).
        lnodes: Number of nodes for long runs (default: 1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongSubmitJobsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_SUBMIT_JOBS_METADATA)
    cargs = []
    cargs.append("long_submit_jobs")
    cargs.extend([
        "--qdec",
        execution.input_file(qdec)
    ])
    cargs.extend([
        "--cdir",
        cdir
    ])
    if bdir is not None:
        cargs.extend([
            "--bdir",
            bdir
        ])
    if ldir is not None:
        cargs.extend([
            "--ldir",
            ldir
        ])
    if scriptsdir is not None:
        cargs.extend([
            "--scriptsdir",
            scriptsdir
        ])
    if cross:
        cargs.append("--cross")
    if base:
        cargs.append("--base")
    if long:
        cargs.append("--long")
    if cflags is not None:
        cargs.extend([
            "--cflags",
            cflags
        ])
    if bflags is not None:
        cargs.extend([
            "--bflags",
            bflags
        ])
    if lflags is not None:
        cargs.extend([
            "--lflags",
            lflags
        ])
    if affine:
        cargs.append("--affine")
    if force:
        cargs.append("--force")
    if simulate:
        cargs.append("--simulate")
    if simfiles:
        cargs.append("--simfiles")
    cargs.append("[--skip]")
    cargs.append("[--skiperror]")
    if check:
        cargs.append("--check")
    cargs.append("[--update-recon-all]")
    cargs.append("[--use-recon-all]")
    if pause is not None:
        cargs.extend([
            "--pause",
            str(pause)
        ])
    if max_ is not None:
        cargs.extend([
            "--max",
            str(max_)
        ])
    if queue_ is not None:
        cargs.extend([
            "--queue",
            queue_
        ])
    if cmem is not None:
        cargs.extend([
            "--cmem",
            str(cmem)
        ])
    if bmem is not None:
        cargs.extend([
            "--bmem",
            str(bmem)
        ])
    if lmem is not None:
        cargs.extend([
            "--lmem",
            str(lmem)
        ])
    if cnodes is not None:
        cargs.extend([
            "--cnodes",
            str(cnodes)
        ])
    if bnodes is not None:
        cargs.extend([
            "--bnodes",
            str(bnodes)
        ])
    if lnodes is not None:
        cargs.extend([
            "--lnodes",
            str(lnodes)
        ])
    ret = LongSubmitJobsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_SUBMIT_JOBS_METADATA",
    "LongSubmitJobsOutputs",
    "long_submit_jobs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_ESTIMATE_WM_METADATA = Metadata(
    id="cac77a4401a904ea7c3d8eb641009c3991349f87.boutiques",
    name="mris_estimate_wm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisEstimateWmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_estimate_wm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_estimate_wm(
    subjs: list[str],
    hemi: str,
    sdir: str | None = None,
    model: str | None = None,
    suffix: str | None = None,
    gpu: bool = False,
    rsi: bool = False,
    single_iter: bool = False,
    vol: str | None = None,
    runner: Runner | None = None,
) -> MrisEstimateWmOutputs:
    """
    Tool to estimate white matter surfaces using MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjs: List of subjects to process.
        hemi: Hemisphere to reconstruct (lh or rh).
        sdir: Override SUBJECTS_DIR.
        model: Override default model.
        suffix: Suffix of output surface (default is 'topofit').
        gpu: Use the GPU.
        rsi: Remove self-intersecting faces during the deformation.
        single_iter: Prevent deformation steps from running more than once.
        vol: Subject volume to use as input.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisEstimateWmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_ESTIMATE_WM_METADATA)
    cargs = []
    cargs.append("mris_estimate_wm")
    cargs.extend([
        "-s",
        *subjs
    ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    if sdir is not None:
        cargs.extend([
            "-d",
            sdir
        ])
    if model is not None:
        cargs.extend([
            "-m",
            model
        ])
    if suffix is not None:
        cargs.extend([
            "-x",
            suffix
        ])
    if gpu:
        cargs.append("-g")
    if rsi:
        cargs.append("--rsi")
    if single_iter:
        cargs.append("--single-iter")
    if vol is not None:
        cargs.extend([
            "--vol",
            vol
        ])
    ret = MrisEstimateWmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_ESTIMATE_WM_METADATA",
    "MrisEstimateWmOutputs",
    "mris_estimate_wm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_QDEC_TABLE_METADATA = Metadata(
    id="3e490486cd37e1e7aa6f857009bf74cde0ba7251.boutiques",
    name="long_qdec_table",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongQdecTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_qdec_table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType | None
    """Output table file generated by the specified operations"""


def long_qdec_table(
    qdec_table: InputPathType,
    split: str | None = None,
    cross_flag: bool = False,
    sort: str | None = None,
    out: str | None = None,
    runner: Runner | None = None,
) -> LongQdecTableOutputs:
    """
    Tool to operate on longitudinal QDEC tables.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec_table: QDEC table file specifying the subjects and time points.
        split: Split table based on column (e.g., use 'fsid-base' to separate\
            subjects).
        cross_flag: Collapse table to cross sectional (one line per subject).
        sort: Sort table based on column within subject (e.g., 'age').
        out: Output file name for operations producing a single table.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongQdecTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_QDEC_TABLE_METADATA)
    cargs = []
    cargs.append("long_qdec_table")
    cargs.extend([
        "--qdec",
        execution.input_file(qdec_table)
    ])
    if split is not None:
        cargs.extend([
            "--split",
            split
        ])
    if cross_flag:
        cargs.append("--cross")
    if sort is not None:
        cargs.extend([
            "--sort",
            sort
        ])
    if out is not None:
        cargs.extend([
            "--out",
            out
        ])
    ret = LongQdecTableOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file(out) if (out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_QDEC_TABLE_METADATA",
    "LongQdecTableOutputs",
    "long_qdec_table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_APPLY_REG_METADATA = Metadata(
    id="40a2e3c6f81394afec96eee658a860b6f21b85f5.boutiques",
    name="mris_apply_reg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisApplyRegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_apply_reg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_result: OutputPathType
    """The output file resulting from registration"""


def mris_apply_reg(
    src_input: InputPathType,
    trg_output: InputPathType,
    streg_pair: str,
    src_label: InputPathType | None = None,
    src_annotation: InputPathType | None = None,
    src_xyz: InputPathType | None = None,
    jacobian: bool = False,
    no_reverse: bool = False,
    rand_noise: bool = False,
    replace_ones: bool = False,
    center_output: bool = False,
    curv_format: bool = False,
    lta_transform: str | None = None,
    lta_patch_transform: str | None = None,
    reverse_surface: str | None = None,
    patch_apply: str | None = None,
    save_vertex_pair: InputPathType | None = None,
    m3z_transform: str | None = None,
    inv_m3z_transform: str | None = None,
    src_reg_scale: float | None = None,
    trg_reg_scale: float | None = None,
    debug_mode: bool = False,
    check_options: bool = False,
    runner: Runner | None = None,
) -> MrisApplyRegOutputs:
    """
    Apply surface registration in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_input: Source values (surface overlay).
        trg_output: Target output file.
        streg_pair: Source and target registration file pair.
        src_label: Source label file (implies --no-rev).
        src_annotation: Source annotation file (implies --no-rev).
        src_xyz: XYZ coordinates from the given surface file as input.
        jacobian: Use jacobian correction.
        no_reverse: Do not do reverse mapping.
        rand_noise: Replace input with white Gaussian noise.
        replace_ones: Replace input with ones.
        center_output: Place the center of the output surface at (0,0,0).
        curv_format: Save output in curvature file format.
        lta_transform: Apply LTA transform to the surface.
        lta_patch_transform: Apply LTA transform to surface patch.
        reverse_surface: LR reverse surface with optional patch.
        patch_apply: Apply patch for each --streg.
        save_vertex_pair: Save vertex pairs from source and target surfaces.
        m3z_transform: Apply M3Z transform.
        inv_m3z_transform: Apply inverse M3Z transform.
        src_reg_scale: Scale the coordinates of the first surface.
        trg_reg_scale: Scale the coordinates of the last surface.
        debug_mode: Turn on debugging.
        check_options: Check options without executing anything.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisApplyRegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_APPLY_REG_METADATA)
    cargs = []
    cargs.append("mris_apply_reg")
    cargs.extend([
        "--src",
        execution.input_file(src_input)
    ])
    cargs.extend([
        "--trg",
        execution.input_file(trg_output)
    ])
    cargs.extend([
        "--streg",
        streg_pair
    ])
    cargs.append("[STREG_ADDITIONAL...]")
    if src_label is not None:
        cargs.extend([
            "--src-label",
            execution.input_file(src_label)
        ])
    if src_annotation is not None:
        cargs.extend([
            "--src-annot",
            execution.input_file(src_annotation)
        ])
    if src_xyz is not None:
        cargs.extend([
            "--src-xyz",
            execution.input_file(src_xyz)
        ])
    if jacobian:
        cargs.append("--jac")
    if no_reverse:
        cargs.append("--no-rev")
    if rand_noise:
        cargs.append("--randn")
    if replace_ones:
        cargs.append("--ones")
    if center_output:
        cargs.append("--center")
    if curv_format:
        cargs.append("--curv")
    if lta_transform is not None:
        cargs.extend([
            "--lta",
            lta_transform
        ])
    if lta_patch_transform is not None:
        cargs.extend([
            "--lta-patch",
            lta_patch_transform
        ])
    if reverse_surface is not None:
        cargs.extend([
            "--reverse",
            reverse_surface
        ])
    if patch_apply is not None:
        cargs.extend([
            "--patch",
            patch_apply
        ])
    if save_vertex_pair is not None:
        cargs.extend([
            "--stvpair",
            execution.input_file(save_vertex_pair)
        ])
    if m3z_transform is not None:
        cargs.extend([
            "--m3z",
            m3z_transform
        ])
    if inv_m3z_transform is not None:
        cargs.extend([
            "--inv-m3z",
            inv_m3z_transform
        ])
    if src_reg_scale is not None:
        cargs.extend([
            "--src-reg-scale",
            str(src_reg_scale)
        ])
    if trg_reg_scale is not None:
        cargs.extend([
            "--trg-reg-scale",
            str(trg_reg_scale)
        ])
    if debug_mode:
        cargs.append("--debug")
    if check_options:
        cargs.append("--checkopts")
    ret = MrisApplyRegOutputs(
        root=execution.output_file("."),
        output_result=execution.output_file(pathlib.Path(trg_output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_APPLY_REG_METADATA",
    "MrisApplyRegOutputs",
    "mris_apply_reg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_MOTION_CORR_STATS_METADATA = Metadata(
    id="d29996fec64fd395bafc8947a76eea2b5d1ba04c.boutiques",
    name="antsMotionCorrStats",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsMotionCorrStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_motion_corr_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_csv: OutputPathType
    """The corrected motion parameters.csv file."""


def ants_motion_corr_stats(
    mask: InputPathType,
    moco_params: InputPathType,
    output: InputPathType,
    transform_index: int | None = None,
    framewise: typing.Literal[0, 1] | None = None,
    spatial_map: bool = False,
    timeseries_displacement: bool = False,
    runner: Runner | None = None,
) -> AntsMotionCorrStatsOutputs:
    """
    Create summary measures of the parameters that are output by antsMotionCorr.
    Currently only works for linear transforms. Outputs the mean and max
    displacements for the voxels within a provided mask, at each time point. By
    default the displacements are relative to the reference space, but the framewise
    option may be used to provide displacements between consecutive time points.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        mask: Mask image - compute displacements within mask.
        moco_params: Motion correction parameters from antsMotionCorr.
        output: Specify the output file.
        transform_index: Specify the index for a 3D transform to output.
        framewise: Do framewise summary stats.
        spatial_map: Output image of displacement magnitude.
        timeseries_displacement: Output 4d time-series image of displacement\
            magnitude.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MOTION_CORR_STATS_METADATA)
    cargs = []
    cargs.append("antsMotionCorrStats")
    cargs.extend([
        "-x",
        execution.input_file(mask)
    ])
    cargs.extend([
        "-m",
        execution.input_file(moco_params)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output)
    ])
    if transform_index is not None:
        cargs.extend([
            "-t",
            str(transform_index)
        ])
    if framewise is not None:
        cargs.extend([
            "-f",
            str(framewise)
        ])
    if spatial_map:
        cargs.append("-s")
    if timeseries_displacement:
        cargs.append("-d")
    ret = AntsMotionCorrStatsOutputs(
        root=execution.output_file("."),
        corrected_csv=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_MOTION_CORR_STATS_METADATA",
    "AntsMotionCorrStatsOutputs",
    "ants_motion_corr_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRFILTER_METADATA = Metadata(
    id="3bb2ab8375a99185acaeac0f9e608829bff091ac.boutiques",
    name="mrfilter",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrfilterVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class MrfilterVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


@dataclasses.dataclass
class MrfilterConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrfilterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrfilter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image."""
    maskout: OutputPathType | None
    """Output a refined mask based on a spatially coherent region with normal
    intensity range. """


def mrfilter(
    input_: InputPathType,
    filter_: str,
    output: str,
    axes: list[int] | None = None,
    inverse: bool = False,
    magnitude: bool = False,
    centre_zero: bool = False,
    stdev: list[float] | None = None,
    magnitude_: bool = False,
    scanner: bool = False,
    extent: list[int] | None = None,
    extent_: list[int] | None = None,
    stdev_: list[float] | None = None,
    fwhm: list[float] | None = None,
    extent_2: list[int] | None = None,
    zupper: float | None = None,
    zlower: float | None = None,
    bridge: int | None = None,
    maskin: InputPathType | None = None,
    maskout: str | None = None,
    strides: typing.Union[MrfilterVariousString, MrfilterVariousFile] | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrfilterConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrfilterOutputs:
    """
    Perform filtering operations on 3D / 4D MR images.
    
    The available filters are: fft, gradient, median, smooth, normalise, zclean.
    
    Each filter has its own unique set of optional parameters.
    
    For 4D images, each 3D volume is processed independently.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: the input image.
        filter_: the type of filter to be applied.
        output: the output image.
        axes: the axes along which to apply the Fourier Transform. By default,\
            the transform is applied along the three spatial axes. Provide as a\
            comma-separate list of axis indices.
        inverse: apply the inverse FFT.
        magnitude: output a magnitude image rather than a complex-valued image.
        centre_zero: re-arrange the FFT results so that the zero-frequency\
            component appears in the centre of the image, rather than at the edges.
        stdev: the standard deviation of the Gaussian kernel used to smooth the\
            input image (in mm). The image is smoothed to reduced large spurious\
            gradients caused by noise. Use this option to override the default\
            stdev of 1 voxel. This can be specified either as a single value to be\
            used for all 3 axes, or as a comma-separated list of 3 values, one for\
            each axis.
        magnitude_: output the gradient magnitude, rather than the default\
            x,y,z components.
        scanner: define the gradient with respect to the scanner coordinate\
            frame of reference.
        extent: specify extent of median filtering neighbourhood in voxels.\
            This can be specified either as a single value to be used for all 3\
            axes, or as a comma-separated list of 3 values, one for each axis\
            (default: 3x3x3).
        extent_: specify extent of normalisation filtering neighbourhood in\
            voxels. This can be specified either as a single value to be used for\
            all 3 axes, or as a comma-separated list of 3 values, one for each axis\
            (default: 3x3x3).
        stdev_: apply Gaussian smoothing with the specified standard deviation.\
            The standard deviation is defined in mm (Default 1 voxel). This can be\
            specified either as a single value to be used for all axes, or as a\
            comma-separated list of the stdev for each axis.
        fwhm: apply Gaussian smoothing with the specified full-width half\
            maximum. The FWHM is defined in mm (Default 1 voxel * 2.3548). This can\
            be specified either as a single value to be used for all axes, or as a\
            comma-separated list of the FWHM for each axis.
        extent_2: specify the extent (width) of kernel size in voxels. This can\
            be specified either as a single value to be used for all axes, or as a\
            comma-separated list of the extent for each axis. The default extent is\
            2 * ceil(2.5 * stdev / voxel_size) - 1.
        zupper: define high intensity outliers: default: 2.5.
        zlower: define low intensity outliers: default: 2.5.
        bridge: number of voxels to gap to fill holes in mask: default: 4.
        maskin: initial mask that defines the maximum spatial extent and the\
            region from which to smaple the intensity range.
        maskout: Output a refined mask based on a spatially coherent region\
            with normal intensity range.
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrfilterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRFILTER_METADATA)
    cargs = []
    cargs.append("mrfilter")
    if axes is not None:
        cargs.extend([
            "-axes",
            *map(str, axes)
        ])
    if inverse:
        cargs.append("-inverse")
    if magnitude:
        cargs.append("-magnitude")
    if centre_zero:
        cargs.append("-centre_zero")
    if stdev is not None:
        cargs.extend([
            "-stdev",
            ",".join(map(str, stdev))
        ])
    if magnitude_:
        cargs.append("-magnitude")
    if scanner:
        cargs.append("-scanner")
    if extent is not None:
        cargs.extend([
            "-extent",
            ",".join(map(str, extent))
        ])
    if extent_ is not None:
        cargs.extend([
            "-extent",
            ",".join(map(str, extent_))
        ])
    if stdev_ is not None:
        cargs.extend([
            "-stdev",
            ",".join(map(str, stdev_))
        ])
    if fwhm is not None:
        cargs.extend([
            "-fwhm",
            ",".join(map(str, fwhm))
        ])
    if extent_2 is not None:
        cargs.extend([
            "-extent",
            ",".join(map(str, extent_2))
        ])
    if zupper is not None:
        cargs.extend([
            "-zupper",
            str(zupper)
        ])
    if zlower is not None:
        cargs.extend([
            "-zlower",
            str(zlower)
        ])
    if bridge is not None:
        cargs.extend([
            "-bridge",
            str(bridge)
        ])
    if maskin is not None:
        cargs.extend([
            "-maskin",
            execution.input_file(maskin)
        ])
    if maskout is not None:
        cargs.extend([
            "-maskout",
            maskout
        ])
    if strides is not None:
        cargs.extend([
            "-strides",
            *strides.run(execution)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(filter_)
    cargs.append(output)
    ret = MrfilterOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
        maskout=execution.output_file(maskout) if (maskout is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRFILTER_METADATA",
    "MrfilterConfig",
    "MrfilterOutputs",
    "MrfilterVariousFile",
    "MrfilterVariousString",
    "mrfilter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_TRAIN_METADATA = Metadata(
    id="18e33eff7b8f70bf5d7c40cd7762266812d2728b.boutiques",
    name="mri_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file_generated: OutputPathType
    """Output file generated by mri_train."""


def mri_train(
    training_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> MriTrainOutputs:
    """
    Tool for training with MRI data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        training_file: Input training file name.
        output_file: Output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_TRAIN_METADATA)
    cargs = []
    cargs.append("mri_train")
    cargs.append(execution.input_file(training_file))
    cargs.append(output_file)
    ret = MriTrainOutputs(
        root=execution.output_file("."),
        output_file_generated=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_TRAIN_METADATA",
    "MriTrainOutputs",
    "mri_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ROI_MODAL_GROW_METADATA = Metadata(
    id="d33815ad6bfc8ff7ac694bacf23eb5bed10577bf.boutiques",
    name="@ROI_modal_grow",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRoiModalGrowOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__roi_modal_grow(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Final output dataset"""


def v__roi_modal_grow(
    input_dset: InputPathType,
    niters: float,
    outdir: str | None = None,
    mask: InputPathType | None = None,
    prefix: str | None = None,
    neighborhood_type: int | None = None,
    runner: Runner | None = None,
) -> VRoiModalGrowOutputs:
    """
    Script to grow a set of regions in a volumetric dataset using modal smoothing.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dset: Required input dataset. This dataset should be a set of\
            integer values, assuming approximate isotropic voxels.
        niters: Number of iterations for modal growth, generally making sense\
            for values from about 1-10.
        outdir: Directory name for output. All output goes to this directory.\
            Default is rmgrow.
        mask: Mask dataset at the same grid as the input dataset. Could be a\
            dilated version of the original mask or a larger region like a cortical\
            ribbon mask. Not required but often desirable.
        prefix: Base name of the final output dataset, i.e., baseprefix.nii.gz.\
            Default is rmg, so output would be rmg.nii.gz.
        neighborhood_type: Neighborhood type used in finding mode. 1 - facing\
            neighbors, 2 - edges, 3 - corners.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRoiModalGrowOutputs`).
    """
    if neighborhood_type is not None and not (1 <= neighborhood_type <= 3): 
        raise ValueError(f"'neighborhood_type' must be between 1 <= x <= 3 but was {neighborhood_type}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ROI_MODAL_GROW_METADATA)
    cargs = []
    cargs.append("@ROI_modal_grow")
    cargs.extend([
        "-input",
        execution.input_file(input_dset)
    ])
    cargs.extend([
        "-niters",
        str(niters)
    ])
    if outdir is not None:
        cargs.extend([
            "-outdir",
            outdir
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if neighborhood_type is not None:
        cargs.extend([
            "-NN",
            str(neighborhood_type)
        ])
    ret = VRoiModalGrowOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(outdir + "/" + prefix + ".nii.gz") if (outdir is not None and prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRoiModalGrowOutputs",
    "V__ROI_MODAL_GROW_METADATA",
    "v__roi_modal_grow",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TCORR_MAP_METADATA = Metadata(
    id="197d89aea57496a500d08e514c10454efb723051.boutiques",
    name="3dTcorrMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTcorrMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tcorr_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_tcorr_map(
    input_: InputPathType,
    seed: InputPathType | None = None,
    mask: InputPathType | None = None,
    automask: bool = False,
    mean: str | None = None,
    zmean: str | None = None,
    qmean: str | None = None,
    pmean: str | None = None,
    thresh: str | None = None,
    varthresh: str | None = None,
    norm_varthresh: str | None = None,
    corrmap: str | None = None,
    corrmask: bool = False,
    aexpr: str | None = None,
    cexpr: str | None = None,
    sexpr: str | None = None,
    hist: str | None = None,
    runner: Runner | None = None,
) -> V3dTcorrMapOutputs:
    """
    AFNI program to compute correlation maps of input time series data.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Read 3D+time dataset 'dd'. This provides the time series to be\
            correlated en masse. This is a mandatory option.
        seed: Read 3D+time dataset 'bb'. It correlates the -seed voxel time\
            series with every voxel in the -input dataset.
        mask: Read dataset 'mmm' as a voxel mask.
        automask: Create a mask from the input dataset.
        mean: Save average correlations into dataset prefix 'pp'.
        zmean: Save tanh of mean arctanh(correlation) into 'pp'.
        qmean: Save RMS(correlation) into 'pp'.
        pmean: Save average of squared positive correlations into 'pp'.
        thresh: Save the COUNT of how many voxels survived thresholding at\
            level abs(correlation) >= tt.
        varthresh: Save the COUNT of how many voxels survive thresholding at\
            multiple levels abs(correlation) >= tt.
        norm_varthresh: Like '-VarThresh', but the output counts are\
            'Normalized'.
        corrmap: Output at each voxel the entire correlation map, into a\
            dataset with prefix 'pp'.
        corrmask: By default, -CorrMap outputs a sub-brick for EACH input\
            dataset voxel. Eliminates these sub-bricks using this option.
        aexpr: For each correlation 'r', compute the calc-style expression\
            'expr', and average these values to get the output that goes into\
            dataset 'ppp'.
        cexpr: As in '-Aexpr', but only average together nonzero values\
            computed by 'expr'.
        sexpr: As above, but the sum of the expressions is computed rather than\
            the average.
        hist: For each voxel, save a histogram of the correlation coefficients\
            into dataset ppp.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTcorrMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TCORR_MAP_METADATA)
    cargs = []
    cargs.append("3dTcorrMap")
    cargs.append(execution.input_file(input_))
    if seed is not None:
        cargs.extend([
            "-seed",
            execution.input_file(seed)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if automask:
        cargs.append("-automask")
    if mean is not None:
        cargs.extend([
            "-Mean",
            mean
        ])
    if zmean is not None:
        cargs.extend([
            "-Zmean",
            zmean
        ])
    if qmean is not None:
        cargs.extend([
            "-Qmean",
            qmean
        ])
    if pmean is not None:
        cargs.extend([
            "-Pmean",
            pmean
        ])
    if thresh is not None:
        cargs.extend([
            "-Thresh",
            thresh
        ])
    if varthresh is not None:
        cargs.extend([
            "-VarThresh",
            varthresh
        ])
    if norm_varthresh is not None:
        cargs.extend([
            "-VarThreshN",
            norm_varthresh
        ])
    if corrmap is not None:
        cargs.extend([
            "-CorrMap",
            corrmap
        ])
    if corrmask:
        cargs.append("-CorrMask")
    if aexpr is not None:
        cargs.extend([
            "-Aexpr",
            aexpr
        ])
    if cexpr is not None:
        cargs.extend([
            "-Cexpr",
            cexpr
        ])
    if sexpr is not None:
        cargs.extend([
            "-Sexpr",
            sexpr
        ])
    if hist is not None:
        cargs.extend([
            "-Hist",
            hist
        ])
    ret = V3dTcorrMapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTcorrMapOutputs",
    "V_3D_TCORR_MAP_METADATA",
    "v_3d_tcorr_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CONFORMIST_METADATA = Metadata(
    id="f609f1b815cd20fa63c94e47456124184827cae8.boutiques",
    name="3dConformist",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dConformistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_conformist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Zero padded output dataset files"""


def v_3d_conformist(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> V3dConformistOutputs:
    """
    Program to conform a collection of datasets to the same size by zero padding.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input datasets to be zero padded to the same size.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dConformistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CONFORMIST_METADATA)
    cargs = []
    cargs.append("3dConformist")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V3dConformistOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dConformistOutputs",
    "V_3D_CONFORMIST_METADATA",
    "v_3d_conformist",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEGMENT_METADATA = Metadata(
    id="0045da93f1222aff1ebe9296139c24c805b6f653.boutiques",
    name="mri_segment",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegmentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_segment(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Segmented white matter output volume"""
    log_file: OutputPathType
    """Log file from segmentation process"""


def mri_segment(
    in_vol: InputPathType,
    out_vol: str,
    no1d_remove: float | None = None,
    slope: float | None = None,
    pslope: float | None = 1.0,
    nslope: float | None = 1.0,
    debug_voxel: list[float] | None = None,
    auto: bool = False,
    noauto: bool = False,
    log: bool = False,
    keep: bool = False,
    gray_hi: float | None = 100.0,
    wm_low: float | None = 80.0,
    wm_low_factor: float | None = None,
    wm_hi: float | None = 125.0,
    nseg: float | None = 20,
    thicken: bool = False,
    fillbg: bool = False,
    fillv: bool = False,
    blur_sigma: float | None = 0.25,
    iterations: float | None = 1,
    thin_strand_limit: float | None = 4,
    verbose: bool = False,
    threshold: float | None = 0.8,
    extract_options: InputPathType | None = None,
    wsize: float | None = 11,
    wsizemm: float | None = None,
    polvw_size: float | None = 5,
    polv_len: float | None = 3,
    datfile: InputPathType | None = None,
    segmentation: str | None = None,
    diagno: float | None = None,
    diag_write: bool = False,
    diag_verbose: bool = False,
    runner: Runner | None = None,
) -> MriSegmentOutputs:
    """
    Segments white matter from the input volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        in_vol: Input volume to be segmented.
        out_vol: Output volume after segmentation.
        no1d_remove: Don't run code that removes 1D strands from segmentation.
        slope: Set the curvature slope (both n and p).
        pslope: Set the curvature pslope (default=1.0).
        nslope: Set the curvature nslope (default=1.0).
        debug_voxel: Set voxel for debugging.
        auto: Automatically detect class statistics (default).
        noauto: Don't automatically detect class statistics.
        log: Log to ./segment.dat.
        keep: Keep wm edits, maintains all values of 1 and 255.
        gray_hi: Set the gray matter high limit (default=100.000).
        wm_low: Set the white matter low limit (default=80.000).
        wm_low_factor: wm_low = f*gray_mean + (1-f)*white_mean;.
        wm_hi: Set the white matter high limit (default=125.000).
        nseg: Thicken the n largest thin strands (default=20).
        thicken: Toggle thickening step (default=ON).
        fillbg: Toggle filling of the basal ganglia (default=OFF).
        fillv: Toggle filling of the ventricles (default=OFF).
        blur_sigma: Set blur sigma (default=0.25).
        iterations: Set # iterations of border classification (default=1).
        thin_strand_limit: Set limit to thin strands in mm (default=4).
        verbose: Verbose.
        threshold: Set % threshold (default=0.80).
        extract_options: Extract options from filename.
        wsize: Set wsize (default=11 voxels).
        wsizemm: Set wsize based on mm instead of voxels.
        polvw_size: Set wsize for plane of least variance (default=5).
        polv_len: Set length for plane of least variance (default=3).
        datfile: Set datfile (default is segment.dat).
        segmentation: Use segmentation to set thresholds.
        diagno: Set diagnostic number.
        diag_write: Set diagnostic write.
        diag_verbose: Set diagnostic verbose.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegmentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEGMENT_METADATA)
    cargs = []
    cargs.append("mri_segment")
    cargs.append(execution.input_file(in_vol))
    cargs.append(out_vol)
    if no1d_remove is not None:
        cargs.extend([
            "-no1d_remove",
            str(no1d_remove)
        ])
    if slope is not None:
        cargs.extend([
            "-slope",
            str(slope)
        ])
    if pslope is not None:
        cargs.extend([
            "-pslope",
            str(pslope)
        ])
    if nslope is not None:
        cargs.extend([
            "-nslope",
            str(nslope)
        ])
    if debug_voxel is not None:
        cargs.extend([
            "-debug_voxel",
            *map(str, debug_voxel)
        ])
    if auto:
        cargs.append("-auto")
    if noauto:
        cargs.append("-noauto")
    if log:
        cargs.append("-log")
    if keep:
        cargs.append("-keep")
    if gray_hi is not None:
        cargs.extend([
            "-ghi",
            str(gray_hi)
        ])
    if wm_low is not None:
        cargs.extend([
            "-wlo",
            str(wm_low)
        ])
    if wm_low_factor is not None:
        cargs.extend([
            "-wm_low_factor",
            str(wm_low_factor)
        ])
    if wm_hi is not None:
        cargs.extend([
            "-whi",
            str(wm_hi)
        ])
    if nseg is not None:
        cargs.extend([
            "-nseg",
            str(nseg)
        ])
    if thicken:
        cargs.append("-thicken")
    if fillbg:
        cargs.append("-fillbg")
    if fillv:
        cargs.append("-fillv")
    if blur_sigma is not None:
        cargs.extend([
            "-b",
            str(blur_sigma)
        ])
    if iterations is not None:
        cargs.extend([
            "-n",
            str(iterations)
        ])
    if thin_strand_limit is not None:
        cargs.extend([
            "-t",
            str(thin_strand_limit)
        ])
    if verbose:
        cargs.append("-v")
    if threshold is not None:
        cargs.extend([
            "-p",
            str(threshold)
        ])
    if extract_options is not None:
        cargs.extend([
            "-x",
            execution.input_file(extract_options)
        ])
    if wsize is not None:
        cargs.extend([
            "-w",
            str(wsize)
        ])
    if wsizemm is not None:
        cargs.extend([
            "-wsizemm",
            str(wsizemm)
        ])
    if polvw_size is not None:
        cargs.extend([
            "-polvwsize",
            str(polvw_size)
        ])
    if polv_len is not None:
        cargs.extend([
            "-polvlen",
            str(polv_len)
        ])
    if datfile is not None:
        cargs.extend([
            "-dat",
            execution.input_file(datfile)
        ])
    if segmentation is not None:
        cargs.extend([
            "-seg",
            segmentation
        ])
    if diagno is not None:
        cargs.extend([
            "-diagno",
            str(diagno)
        ])
    if diag_write:
        cargs.append("-diag-write")
    if diag_verbose:
        cargs.append("-diag-verbose")
    ret = MriSegmentOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(out_vol),
        log_file=execution.output_file("./segment.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEGMENT_METADATA",
    "MriSegmentOutputs",
    "mri_segment",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GET_AFNI_MODEL_PRF_6_METADATA = Metadata(
    id="a1644a25504c74d6961d86251212dfc9c7f6fb99.boutiques",
    name="get_afni_model_PRF_6",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GetAfniModelPrf6Outputs(typing.NamedTuple):
    """
    Output object returned when calling `get_afni_model_prf_6(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def get_afni_model_prf_6(
    nt_: float,
    amp: float,
    x: float,
    y: float,
    sigma: float,
    sigrat: float,
    theta: float,
    runner: Runner | None = None,
) -> GetAfniModelPrf6Outputs:
    """
    A command to invoke AFNI's population receptive field (pRF) model.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        nt_: Number of time points of the stimulus dataset.
        amp: Amplitude of the pRF model.
        x: X coordinate of the pRF center.
        y: Y coordinate of the pRF center.
        sigma: Standard deviation of the Gaussian pRF.
        sigrat: Ratio of standard deviations (sigma_x/sigma_y) of the Gaussian\
            pRF.
        theta: Rotation angle theta of the Gaussian pRF.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetAfniModelPrf6Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GET_AFNI_MODEL_PRF_6_METADATA)
    cargs = []
    cargs.append("get_afni_model_PRF_6")
    cargs.append(str(nt_))
    cargs.append(str(amp))
    cargs.append(str(x))
    cargs.append(str(y))
    cargs.append(str(sigma))
    cargs.append(str(sigrat))
    cargs.append(str(theta))
    ret = GetAfniModelPrf6Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GET_AFNI_MODEL_PRF_6_METADATA",
    "GetAfniModelPrf6Outputs",
    "get_afni_model_prf_6",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRIDEC_METADATA = Metadata(
    id="8f7bd0a6993abb2339230891eb8c52ffadaa9441.boutiques",
    name="tridec",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TridecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tridec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file from tridec processing."""


def tridec(
    subject_name: str,
    fine_file: InputPathType,
    ico_file: InputPathType,
    out_file: str,
    runner: Runner | None = None,
) -> TridecOutputs:
    """
    Tridec tool for processing brain images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject being processed.
        fine_file: Fine file input for tridec.
        ico_file: ICO file input for tridec.
        out_file: Output file for tridec processing result.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TridecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRIDEC_METADATA)
    cargs = []
    cargs.append("tridec")
    cargs.append(subject_name)
    cargs.append(execution.input_file(fine_file))
    cargs.append(execution.input_file(ico_file))
    cargs.append(out_file)
    ret = TridecOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(out_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRIDEC_METADATA",
    "TridecOutputs",
    "tridec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MTNORMALISE_METADATA = Metadata(
    id="3709b0ca1455372ea3dda75e22e31168270b187c.boutiques",
    name="mtnormalise",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MtnormaliseConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MtnormaliseInputOutputOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[MtnormaliseInputOutput](...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """output normalised tissue compartment image."""


@dataclasses.dataclass
class MtnormaliseInputOutput:
    """
    list of all input and output tissue compartment files (see example usage).
    """
    input_: InputPathType
    """input tissue compartment image."""
    output: str
    """output normalised tissue compartment image."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.input_))
        cargs.append(self.output)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> MtnormaliseInputOutputOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `MtnormaliseInputOutputOutputs`).
        """
        ret = MtnormaliseInputOutputOutputs(
            root=execution.output_file("."),
            output=execution.output_file(self.output),
        )
        return ret


class MtnormaliseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mtnormalise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    check_norm: OutputPathType | None
    """output the final estimated spatially varying intensity level that is used
    for normalisation. """
    check_mask: OutputPathType | None
    """output the final mask used to compute the normalisation. This mask
    excludes regions identified as outliers by the optimisation process. """
    check_factors: OutputPathType | None
    """output the tissue balance factors computed during normalisation. """
    input_output: list[MtnormaliseInputOutputOutputs]
    """Outputs from `MtnormaliseInputOutput`.This is a list of outputs with the
    same length and order as the inputs."""


def mtnormalise(
    mask: InputPathType,
    input_output: list[MtnormaliseInputOutput],
    order: str | None = None,
    niter: list[int] | None = None,
    reference: float | None = None,
    balanced: bool = False,
    check_norm: str | None = None,
    check_mask: str | None = None,
    check_factors: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MtnormaliseConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MtnormaliseOutputs:
    """
    Multi-tissue informed log-domain intensity normalisation.
    
    This command takes as input any number of tissue components (e.g. from
    multi-tissue CSD) and outputs corresponding normalised tissue components
    corrected for the effects of (residual) intensity inhomogeneities. Intensity
    normalisation is performed by optimising the voxel-wise sum of all tissue
    compartments towards a constant value, under constraints of spatial
    smoothness (polynomial basis of a given order). Different to the Raffelt et
    al. 2017 abstract, this algorithm performs this task in the log-domain
    instead, with added gradual outlier rejection, different handling of the
    balancing factors between tissue compartments and a different iteration
    structure.
    
    The -mask option is mandatory and is optimally provided with a brain mask
    (such as the one obtained from dwi2mask earlier in the processing pipeline).
    Outlier areas with exceptionally low or high combined tissue contributions
    are accounted for and reoptimised as the intensity inhomogeneity estimation
    becomes more accurate.
    
    References:
    
    Raffelt, D.; Dhollander, T.; Tournier, J.-D.; Tabbara, R.; Smith, R. E.;
    Pierre, E. & Connelly, A. Bias Field Correction and Intensity Normalisation
    for Quantitative Analysis of Apparent Fibre Density. In Proc. ISMRM, 2017,
    26, 3541
    
    Dhollander, T.; Tabbara, R.; Rosnarho-Tornstrand, J.; Tournier, J.-D.;
    Raffelt, D. & Connelly, A. Multi-tissue log-domain intensity and
    inhomogeneity normalisation for quantitative apparent fibre density. In
    Proc. ISMRM, 2021, 29, 2472.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        mask: the mask defines the data used to compute the intensity\
            normalisation. This option is mandatory.
        input_output: list of all input and output tissue compartment files\
            (see example usage).
        order: the maximum order of the polynomial basis used to fit the\
            normalisation field in the log-domain. An order of 0 is equivalent to\
            not allowing spatial variance of the intensity normalisation factor.\
            (default: 3).
        niter: set the number of iterations. The first (and potentially only)\
            entry applies to the main loop. If supplied as a comma-separated list\
            of integers, the second entry applies to the inner loop to update the\
            balance factors (default: 15,7).
        reference: specify the (positive) reference value to which the summed\
            tissue compartments will be normalised. (default: 0.282095, SH DC term\
            for unit angular integral).
        balanced: incorporate the per-tissue balancing factors into scaling of\
            the output images (NOTE: use of this option has critical consequences\
            for AFD intensity normalisation; should not be used unless these\
            consequences are fully understood).
        check_norm: output the final estimated spatially varying intensity\
            level that is used for normalisation.
        check_mask: output the final mask used to compute the normalisation.\
            This mask excludes regions identified as outliers by the optimisation\
            process.
        check_factors: output the tissue balance factors computed during\
            normalisation.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MtnormaliseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MTNORMALISE_METADATA)
    cargs = []
    cargs.append("mtnormalise")
    cargs.extend([
        "-mask",
        execution.input_file(mask)
    ])
    if order is not None:
        cargs.extend([
            "-order",
            order
        ])
    if niter is not None:
        cargs.extend([
            "-niter",
            ",".join(map(str, niter))
        ])
    if reference is not None:
        cargs.extend([
            "-reference",
            str(reference)
        ])
    if balanced:
        cargs.append("-balanced")
    if check_norm is not None:
        cargs.extend([
            "-check_norm",
            check_norm
        ])
    if check_mask is not None:
        cargs.extend([
            "-check_mask",
            check_mask
        ])
    if check_factors is not None:
        cargs.extend([
            "-check_factors",
            check_factors
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend([a for c in [s.run(execution) for s in input_output] for a in c])
    ret = MtnormaliseOutputs(
        root=execution.output_file("."),
        check_norm=execution.output_file(check_norm) if (check_norm is not None) else None,
        check_mask=execution.output_file(check_mask) if (check_mask is not None) else None,
        check_factors=execution.output_file(check_factors) if (check_factors is not None) else None,
        input_output=[i.outputs(execution) if hasattr(i, "outputs") else None for i in input_output],
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MTNORMALISE_METADATA",
    "MtnormaliseConfig",
    "MtnormaliseInputOutput",
    "MtnormaliseInputOutputOutputs",
    "MtnormaliseOutputs",
    "mtnormalise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TEST_TUTORIALS_SH_METADATA = Metadata(
    id="12b91716710dd5b63abd67223200ca5920aafcec.boutiques",
    name="test_tutorials.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TestTutorialsShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `test_tutorials_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def test_tutorials_sh(
    all_tutorials: bool = False,
    quick_test: bool = False,
    auto_quit_freeview: bool = False,
    skip_all_guis: bool = False,
    skip_tk_guis: bool = False,
    skip_qdec_guis: bool = False,
    individual_subject: bool = False,
    troubleshooting: bool = False,
    group_analysis: bool = False,
    qdec: bool = False,
    longitudinal: bool = False,
    roi_analysis: bool = False,
    diffusion: bool = False,
    tracula: bool = False,
    fsfast: bool = False,
    multimodal: bool = False,
    runner: Runner | None = None,
) -> TestTutorialsShOutputs:
    """
    A script to run various tutorial commands, with options for skipping GUI
    components and focusing on specific tutorials.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        all_tutorials: Run all tutorials.
        quick_test: Perform a quick subset of commands.
        auto_quit_freeview: Automatically closes freeview after opening.
        skip_all_guis: Skips all commands that open a GUI.
        skip_tk_guis: Skips commands that open a tk GUI (tkmedit, tksurfer,\
            etc).
        skip_qdec_guis: Skips commands that open qdec.
        individual_subject: Do Interaction with Individual Subject Data\
            tutorial.
        troubleshooting: Do Troubleshooting tutorial.
        group_analysis: Do Group Analysis tutorial.
        qdec: Do QDEC tutorial.
        longitudinal: Do Longitudinal tutorial.
        roi_analysis: Do ROI Analysis tutorial.
        diffusion: Do Diffusion tutorial.
        tracula: Do TRACULA tutorial.
        fsfast: Do FSFASt tutorial.
        multimodal: Do Mulimodal tutorial.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TestTutorialsShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TEST_TUTORIALS_SH_METADATA)
    cargs = []
    cargs.append("test_tutorials.sh")
    if all_tutorials:
        cargs.append("-all")
    if quick_test:
        cargs.append("-quick")
    if auto_quit_freeview:
        cargs.append("-auto_quit_freeview")
    if skip_all_guis:
        cargs.append("-skip_all_guis")
    if skip_tk_guis:
        cargs.append("-skip_tk_guis")
    if skip_qdec_guis:
        cargs.append("-skip_qdec_guis")
    if individual_subject:
        cargs.append("-individual_subject")
    if troubleshooting:
        cargs.append("-troubleshooting")
    if group_analysis:
        cargs.append("-group_analysis")
    if qdec:
        cargs.append("-qdec")
    if longitudinal:
        cargs.append("-longitudinal")
    if roi_analysis:
        cargs.append("-roi_analysis")
    if diffusion:
        cargs.append("-diffusion")
    if tracula:
        cargs.append("-tracula")
    if fsfast:
        cargs.append("-fsfast")
    if multimodal:
        cargs.append("-multimodal")
    ret = TestTutorialsShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TEST_TUTORIALS_SH_METADATA",
    "TestTutorialsShOutputs",
    "test_tutorials_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GROUPSTATS_METADATA = Metadata(
    id="b3ed2b7c0070683b40d589d0c64dbdd96b53715f.boutiques",
    name="groupstats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GroupstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `groupstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files generated by groupstats."""


def groupstats(
    outdir: str,
    subjectfile: InputPathType | None = None,
    fwhm: list[float] | None = None,
    subject_dir: str | None = None,
    mapname: str | None = None,
    srcsurfreg: str | None = None,
    keep53: bool = False,
    runner: Runner | None = None,
) -> GroupstatsOutputs:
    """
    A script for comprehensive group analysis on both maps and ROI results within
    FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        outdir: Output folder.
        subjectfile: Subject list file.
        fwhm: Specify smoothing level(s).
        subject_dir: Subject directory.
        mapname: Use the given map name.
        srcsurfreg: Source surface registration (default is sphere.reg).
        keep53: Keep 5.3 aseg names (e.g., Thalamus-Proper).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GroupstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GROUPSTATS_METADATA)
    cargs = []
    cargs.append("groupstats")
    cargs.extend([
        "--o",
        outdir
    ])
    if subjectfile is not None:
        cargs.extend([
            "--f",
            execution.input_file(subjectfile)
        ])
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            *map(str, fwhm)
        ])
    if subject_dir is not None:
        cargs.extend([
            "--sd",
            subject_dir
        ])
    if mapname is not None:
        cargs.extend([
            "--m",
            mapname
        ])
    if srcsurfreg is not None:
        cargs.extend([
            "--srcsurfreg",
            srcsurfreg
        ])
    if keep53:
        cargs.append("--keep53")
    ret = GroupstatsOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(outdir + "/<output_file>.ext"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GROUPSTATS_METADATA",
    "GroupstatsOutputs",
    "groupstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_RF_TRAIN_METADATA = Metadata(
    id="ed47732236da2816714345ea0516a2a3309483a8.boutiques",
    name="mris_rf_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRfTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_rf_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_rf_train(
    subjects: list[str],
    output_name: str,
    hemi: str | None = None,
    surf: str | None = None,
    runner: Runner | None = None,
) -> MrisRfTrainOutputs:
    """
    Tool for training a random forest classifier using MRIS surface data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: List of subjects to process.
        output_name: Output name for the trained model.
        hemi: Process specified hemisphere instead of the default 'lh'.
        surf: Change the default surface name from 'white' to the specified\
            surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRfTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_RF_TRAIN_METADATA)
    cargs = []
    cargs.append("mris_rf_train")
    cargs.extend(subjects)
    cargs.append(output_name)
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    ret = MrisRfTrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_RF_TRAIN_METADATA",
    "MrisRfTrainOutputs",
    "mris_rf_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COMPUTE_CHANGE_MAP_METADATA = Metadata(
    id="4cf0713520dd67c2b0f360d78cb6a13011d05e50.boutiques",
    name="mri_compute_change_map",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriComputeChangeMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_compute_change_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_change_map: OutputPathType
    """Output change map registered with Volume 1"""


def mri_compute_change_map(
    volume1: InputPathType,
    volume2: InputPathType,
    transform: InputPathType,
    outvolume: str,
    mean_filter: bool = False,
    gaussian_sigma: float | None = None,
    runner: Runner | None = None,
) -> MriComputeChangeMapOutputs:
    """
    Compute the change map between two MRI volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volume1: First volume (e.g. volume1.mgz).
        volume2: Second volume, transformed into the space of Volume 1 (e.g.\
            volume2.mgz).
        transform: Transform that takes Volume 2 coordinates into Volume 1\
            space.
        outvolume: Output change map volume (e.g. change_map.mgz).
        mean_filter: Apply mean filter to the output before writing.
        gaussian_sigma: Smooth with Gaussian filter of specified sigma before\
            writing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriComputeChangeMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COMPUTE_CHANGE_MAP_METADATA)
    cargs = []
    cargs.append("mri_compute_change_map")
    if mean_filter:
        cargs.append("-m")
    if gaussian_sigma is not None:
        cargs.extend([
            "-s",
            str(gaussian_sigma)
        ])
    cargs.append(execution.input_file(volume1))
    cargs.append(execution.input_file(volume2))
    cargs.append(execution.input_file(transform))
    cargs.append(outvolume)
    ret = MriComputeChangeMapOutputs(
        root=execution.output_file("."),
        out_change_map=execution.output_file(outvolume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COMPUTE_CHANGE_MAP_METADATA",
    "MriComputeChangeMapOutputs",
    "mri_compute_change_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_NEW_METADATA = Metadata(
    id="c3ea7e0b28d39449428a797435fdabb03c6243ca.boutiques",
    name="inflate_subject_new",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectNewOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_new(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_new(
    subject_dir: str,
    runner: Runner | None = None,
) -> InflateSubjectNewOutputs:
    """
    Tool to inflate subject surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Directory containing the subject data to be inflated.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectNewOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_NEW_METADATA)
    cargs = []
    cargs.append("inflate_subject_new")
    cargs.append(subject_dir)
    ret = InflateSubjectNewOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_NEW_METADATA",
    "InflateSubjectNewOutputs",
    "inflate_subject_new",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_GROUP_BY_ENDPOINTS_METADATA = Metadata(
    id="87310592b138bba2f86c81c258d64cefe1c90e23.boutiques",
    name="dmri_groupByEndpoints",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriGroupByEndpointsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_group_by_endpoints(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_group_by_endpoints(
    streamline_file: InputPathType,
    image_file: InputPathType,
    output_directory: str,
    runner: Runner | None = None,
) -> DmriGroupByEndpointsOutputs:
    """
    A tool to group streamlines by their endpoints using diffusion MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        streamline_file: The file containing streamline data.
        image_file: The image file to be used in grouping.
        output_directory: The directory where output will be saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriGroupByEndpointsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_GROUP_BY_ENDPOINTS_METADATA)
    cargs = []
    cargs.append("dmri_groupByEndpoints")
    cargs.extend([
        "-s",
        execution.input_file(streamline_file)
    ])
    cargs.extend([
        "-i",
        execution.input_file(image_file)
    ])
    cargs.extend([
        "-d",
        output_directory
    ])
    ret = DmriGroupByEndpointsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_GROUP_BY_ENDPOINTS_METADATA",
    "DmriGroupByEndpointsOutputs",
    "dmri_group_by_endpoints",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ALIGN_EPI_ANAT_METADATA = Metadata(
    id="8b0229305647603bf69640345954c0975124bb02.boutiques",
    name="align_epi_anat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AlignEpiAnatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `align_epi_anat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    anat_aligned: OutputPathType
    """A version of the anatomy that is aligned to the EPI"""
    epi_aligned: OutputPathType
    """A version of the EPI dataset aligned to the Anatomy"""


def align_epi_anat(
    epi: InputPathType,
    anat: InputPathType,
    epi_base: str,
    anat2epi: bool = False,
    epi2anat: bool = False,
    suffix: str | None = None,
    add_edge: bool = False,
    big_move: bool = False,
    giant_move: bool = False,
    ginormous_move: bool = False,
    keep_rm_files: bool = False,
    prep_only: bool = False,
    ana_has_skull: typing.Literal["yes", "no"] | None = None,
    epi_strip: typing.Literal["3dSkullStrip", "3dAutomask", "None"] | None = None,
    volreg_method: typing.Literal["3dvolreg", "3dWarpDrive", "3dAllineate"] | None = None,
    ex_mode: typing.Literal["quiet", "echo", "dry_run", "script"] | None = None,
    overwrite: bool = False,
    runner: Runner | None = None,
) -> AlignEpiAnatOutputs:
    """
    Align EPI to anatomical datasets or vice versa.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        epi: EPI dataset to align or to which to align.
        anat: Anatomical dataset to align or to which to align.
        epi_base: Base sub-brick to use for alignment\
            (0/mean/median/max/subbrick#).
        anat2epi: Align anatomical to EPI dataset (default).
        epi2anat: Align EPI to anatomical dataset.
        suffix: Append suffix to the original anat/epi dataset to use in the\
            resulting dataset names.
        add_edge: Run @AddEdge script to create composite edge images.
        big_move: Large displacement is needed to align the two volumes.
        giant_move: Even larger movement required, uses cmass, two passes and\
            very large angles and shifts.
        ginormous_move: Adds align_centers to giant_move.
        keep_rm_files: Don't delete any of the temporary files created.
        prep_only: Do preprocessing steps only without alignment.
        ana_has_skull: Do not skullstrip anat dataset.
        epi_strip: Method to remove skull for EPI data.
        volreg_method: Time series volume registration method.
        ex_mode: Command execution mode.
        overwrite: Overwrite existing files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AlignEpiAnatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ALIGN_EPI_ANAT_METADATA)
    cargs = []
    cargs.append("align_epi_anat.py")
    cargs.extend([
        "-epi",
        execution.input_file(epi)
    ])
    cargs.extend([
        "-anat",
        execution.input_file(anat)
    ])
    cargs.extend([
        "-epi_base",
        epi_base
    ])
    if anat2epi:
        cargs.append("-anat2epi")
    if epi2anat:
        cargs.append("-epi2anat")
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    if add_edge:
        cargs.append("-AddEdge")
    if big_move:
        cargs.append("-big_move")
    if giant_move:
        cargs.append("-giant_move")
    if ginormous_move:
        cargs.append("-ginormous_move")
    if keep_rm_files:
        cargs.append("-keep_rm_files")
    if prep_only:
        cargs.append("-prep_only")
    if ana_has_skull is not None:
        cargs.extend([
            "-anat_has_skull",
            ana_has_skull
        ])
    if epi_strip is not None:
        cargs.extend([
            "-epi_strip",
            epi_strip
        ])
    if volreg_method is not None:
        cargs.extend([
            "-volreg_method",
            volreg_method
        ])
    if ex_mode is not None:
        cargs.extend([
            "-ex_mode",
            ex_mode
        ])
    if overwrite:
        cargs.append("-overwrite")
    ret = AlignEpiAnatOutputs(
        root=execution.output_file("."),
        anat_aligned=execution.output_file(pathlib.Path(anat).name + "+orig"),
        epi_aligned=execution.output_file(pathlib.Path(epi).name + "+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ALIGN_EPI_ANAT_METADATA",
    "AlignEpiAnatOutputs",
    "align_epi_anat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APAS2ASEG_METADATA = Metadata(
    id="3dc0c23b67aed06f4f6b85f8abfcfff2224cf026.boutiques",
    name="apas2aseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Apas2asegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `apas2aseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_seg_file: OutputPathType | None
    """The output segmentation file resulting from the conversion process."""


def apas2aseg(
    subject: str | None = None,
    input_aparc_aseg: InputPathType | None = None,
    output_seg: str | None = "apas-aseg.mgz",
    runner: Runner | None = None,
) -> Apas2asegOutputs:
    """
    Converts aparc+aseg.mgz into aseg.mgz-like format by replacing specific cortical
    segmentations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier specifying the directory where the\
            subject's data is stored.
        input_aparc_aseg: Input aparc+aseg.mgz file to be converted.
        output_seg: Output file for the new segmentation (e.g., apas-aseg.mgz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Apas2asegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APAS2ASEG_METADATA)
    cargs = []
    cargs.append("apas2aseg")
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if input_aparc_aseg is not None:
        cargs.extend([
            "--i",
            execution.input_file(input_aparc_aseg)
        ])
    if output_seg is not None:
        cargs.extend([
            "--o",
            output_seg
        ])
    ret = Apas2asegOutputs(
        root=execution.output_file("."),
        output_seg_file=execution.output_file(output_seg) if (output_seg is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APAS2ASEG_METADATA",
    "Apas2asegOutputs",
    "apas2aseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FNIRTFILEUTILS_METADATA = Metadata(
    id="3602fcba77f3571ce6633e4b77bf43d5c917943e.boutiques",
    name="fnirtfileutils",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FnirtfileutilsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fnirtfileutils(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_field_file: OutputPathType | None
    """Output field or coefficient volume"""
    jacobian_output_file: OutputPathType | None
    """Output jacobian determinant map volume"""
    jacobian_matrix_file: OutputPathType | None
    """Output full jacobian matrix 4D-map volume"""


def fnirtfileutils(
    input_coefs: InputPathType,
    ref_volume: InputPathType | None = None,
    out_field: str | None = None,
    output_format: str | None = "field",
    warp_res: float | None = None,
    knot_space: float | None = None,
    jacobian_output: str | None = None,
    jacobian_matrix_output: str | None = None,
    with_aff: bool = False,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> FnirtfileutilsOutputs:
    """
    FNIRT file utilities for FSL - Converts FNIRT warp field coefficients to other
    formats.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_coefs: Filename of input coefficient volume to be converted.
        ref_volume: Filename for reference volume.
        out_field: Filename for output field/coef volume - uses relative warp\
            convention.
        output_format: Output format [field, spline], default=field.
        warp_res: Warp resolution (mm), only relevant when --outformat=spline.
        knot_space: Knot-spacing (voxels), only relevant when\
            --outformat=spline.
        jacobian_output: Filename for output jacobian determinant map volume.
        jacobian_matrix_output: Filename for output full jacobian matrix 4D-map\
            volume.
        with_aff: If set, the affine transform is included in the\
            field/jacobian.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display this help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FnirtfileutilsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FNIRTFILEUTILS_METADATA)
    cargs = []
    cargs.append("fnirtfileutils")
    cargs.extend([
        "--in",
        execution.input_file(input_coefs)
    ])
    if ref_volume is not None:
        cargs.extend([
            "--ref",
            execution.input_file(ref_volume)
        ])
    if out_field is not None:
        cargs.extend([
            "--out",
            out_field
        ])
    if output_format is not None:
        cargs.extend([
            "--outformat",
            output_format
        ])
    if warp_res is not None:
        cargs.extend([
            "--warpres",
            str(warp_res)
        ])
    if knot_space is not None:
        cargs.extend([
            "--knotspace",
            str(knot_space)
        ])
    if jacobian_output is not None:
        cargs.extend([
            "--jac",
            jacobian_output
        ])
    if jacobian_matrix_output is not None:
        cargs.extend([
            "--matjac",
            jacobian_matrix_output
        ])
    if with_aff:
        cargs.append("--withaff")
    if verbose_flag:
        cargs.append("--verbose")
    if help_flag:
        cargs.append("--help")
    ret = FnirtfileutilsOutputs(
        root=execution.output_file("."),
        output_field_file=execution.output_file(out_field + ".nii.gz") if (out_field is not None) else None,
        jacobian_output_file=execution.output_file(jacobian_output + ".nii.gz") if (jacobian_output is not None) else None,
        jacobian_matrix_file=execution.output_file(jacobian_matrix_output + ".nii.gz") if (jacobian_matrix_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FNIRTFILEUTILS_METADATA",
    "FnirtfileutilsOutputs",
    "fnirtfileutils",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSCALC_FSL_METADATA = Metadata(
    id="a318448c0ae9ee2486a72de6136c2f2bdab8a57e.boutiques",
    name="fscalc.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FscalcFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fscalc_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file"""


def fscalc_fsl(
    input_file: InputPathType,
    output_file: str,
    additional_options: str | None = None,
    runner: Runner | None = None,
) -> FscalcFslOutputs:
    """
    A Freesurfer wrapper around fslmaths, allowing input and output formats
    compatible with Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input image file readable by Freesurfer.
        output_file: Output image file writable by Freesurfer.
        additional_options: Additional fslmaths-specific options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FscalcFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSCALC_FSL_METADATA)
    cargs = []
    cargs.append("fscalc.fsl")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if additional_options is not None:
        cargs.append(additional_options)
    ret = FscalcFslOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSCALC_FSL_METADATA",
    "FscalcFslOutputs",
    "fscalc_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ASEG2FEAT_METADATA = Metadata(
    id="a171951e01eefa6d930d2f5fc71421003b6f23e3.boutiques",
    name="aseg2feat",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Aseg2featOutputs(typing.NamedTuple):
    """
    Output object returned when calling `aseg2feat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType
    """Result segmentation in FEAT functional space."""
    stats_output: OutputPathType
    """Directory where results are saved when using --svstats."""


def aseg2feat(
    feat: str,
    featdirfile: InputPathType | None = None,
    seg: str | None = None,
    aparc_aseg: bool = False,
    svstats: bool = False,
    standard: bool = False,
    debug: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Aseg2featOutputs:
    """
    Resamples the FreeSurfer automatic subcortical segmentation (aseg) to the FEAT
    functional space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        feat: FEAT output directory. Multiple --feat arguments can be supplied.
        featdirfile: File with a list of FEAT directories. Can be used in\
            conjunction with --feat.
        seg: Change segmentation volume, default is aseg.
        aparc_aseg: Use aparc+aseg.mgz. Same as --seg aparc+aseg.mgz.
        svstats: Save result in featdir/stats instead of featdir/reg/freesurfer.
        standard: Map results to standard space instead of native functional\
            space. Implies --svstats.
        debug: Turn on debugging.
        help_: Print help and exit.
        version: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Aseg2featOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ASEG2FEAT_METADATA)
    cargs = []
    cargs.append("aseg2feat")
    cargs.extend([
        "--feat",
        feat
    ])
    if featdirfile is not None:
        cargs.extend([
            "--featdirfile",
            execution.input_file(featdirfile)
        ])
    if seg is not None:
        cargs.extend([
            "--seg",
            seg
        ])
    if aparc_aseg:
        cargs.append("--aparc+aseg")
    if svstats:
        cargs.append("--svstats")
    if standard:
        cargs.append("--standard")
    if debug:
        cargs.append("--debug")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = Aseg2featOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(feat + "/reg/freesurfer/aseg.nii.gz"),
        stats_output=execution.output_file(feat + "/stats"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ASEG2FEAT_METADATA",
    "Aseg2featOutputs",
    "aseg2feat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PREDICT_V1_SH_METADATA = Metadata(
    id="9dad70e954292a5df8dae706ae1d13ad401174c0.boutiques",
    name="predict_v1.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class PredictV1ShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `predict_v1_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def predict_v1_sh(
    subjects: list[str],
    template: str | None = None,
    inflated_surface_flag: bool = False,
    hemisphere: str | None = None,
    print_mode_flag: bool = False,
    runner: Runner | None = None,
) -> PredictV1ShOutputs:
    """
    A script for predicting brain images using registration.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: Subjects for prediction.
        template: Target image for registration (exvivo or invivo [default]).
        inflated_surface_flag: Don't use inflated surface as initial\
            registration (backward compatibility).
        hemisphere: Hemisphere (rh or lh) default is both hemispheres.
        print_mode_flag: Print mode (do not run commands, just print them).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PredictV1ShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PREDICT_V1_SH_METADATA)
    cargs = []
    cargs.append("predict_v1.sh")
    if template is not None:
        cargs.extend([
            "-t",
            template
        ])
    if inflated_surface_flag:
        cargs.append("-i")
    if hemisphere is not None:
        cargs.extend([
            "-h",
            hemisphere
        ])
    if print_mode_flag:
        cargs.append("-p")
    cargs.append("".join(subjects) + "...")
    ret = PredictV1ShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PREDICT_V1_SH_METADATA",
    "PredictV1ShOutputs",
    "predict_v1_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LMER_METADATA = Metadata(
    id="02e68dcb59ede0c18ce18893dd5aa84a50513efe.boutiques",
    name="3dLMEr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLmerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_lmer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file"""
    residuals_file: OutputPathType | None
    """Output residuals file"""


def v_3d_lmer(
    data_table: InputPathType,
    model: str,
    prefix: str,
    bound_lower: float | None = None,
    bound_upper: float | None = None,
    cio: bool = False,
    debug_args: bool = False,
    glf_code: str | None = None,
    glt_code: str | None = None,
    help_: bool = False,
    input_file_column: str | None = None,
    jobs: float | None = None,
    mask: InputPathType | None = None,
    qvar_centers: str | None = None,
    qvars: str | None = None,
    resid: str | None = None,
    rio: bool = False,
    show_options: bool = False,
    ss_type: float | None = None,
    trr: bool = False,
    vvar_centers: str | None = None,
    vvars: str | None = None,
    runner: Runner | None = None,
) -> V3dLmerOutputs:
    """
    Program for Voxelwise Linear Mixed-Effects (LME) Analysis.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        data_table: List the data structure with a header as the first line.
        model: Specify the model structure for all the variables.
        prefix: Output file name.
        bound_lower: Specify the lower and upper bounds for outlier removal.
        bound_upper: Specify the lower and upper bounds for outlier removal.
        cio: Use AFNI's C io functions.
        debug_args: Enable R to save the parameters for debugging.
        glf_code: Specify a general linear F-style (GLF) formulation.
        glt_code: Specify the label and weights of interest in a general linear\
            t-style (GLT) formulation.
        help_: Display the help message.
        input_file_column: Specify the column name for input files of effect\
            estimate.
        jobs: Number of jobs for parallel computing.
        mask: Process voxels inside this mask only.
        qvar_centers: Specify centering values for quantitative variables.
        qvars: Identify quantitative variables (or covariates).
        resid: Output file name for the residuals.
        rio: Use R's io functions.
        show_options: List of allowed options.
        ss_type: Specify the type for sums of squares in the F-statistics.
        trr: Perform test-retest reliability analysis.
        vvar_centers: Specify centering values for voxel-wise covariates.
        vvars: Identify voxel-wise covariates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLmerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LMER_METADATA)
    cargs = []
    cargs.append("3dLMEr")
    if bound_lower is not None:
        cargs.append(str(bound_lower))
    if bound_upper is not None:
        cargs.append(str(bound_upper))
    if cio:
        cargs.append("-cio")
    cargs.extend([
        "-dataTable",
        execution.input_file(data_table)
    ])
    if debug_args:
        cargs.append("-dbgArgs")
    if glf_code is not None:
        cargs.extend([
            "-glfCode",
            glf_code
        ])
    if glt_code is not None:
        cargs.extend([
            "-gltCode",
            glt_code
        ])
    if help_:
        cargs.append("-help")
    if input_file_column is not None:
        cargs.extend([
            "-IF",
            input_file_column
        ])
    if jobs is not None:
        cargs.extend([
            "-jobs",
            str(jobs)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.extend([
        "-model",
        model
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if qvar_centers is not None:
        cargs.extend([
            "-qVarCenters",
            qvar_centers
        ])
    if qvars is not None:
        cargs.extend([
            "-qVars",
            qvars
        ])
    if resid is not None:
        cargs.extend([
            "-resid",
            resid
        ])
    if rio:
        cargs.append("-Rio")
    if show_options:
        cargs.append("-show_allowed_options")
    if ss_type is not None:
        cargs.extend([
            "-SS_type",
            str(ss_type)
        ])
    if trr:
        cargs.append("-TRR")
    if vvar_centers is not None:
        cargs.extend([
            "-vVarCenters",
            vvar_centers
        ])
    if vvars is not None:
        cargs.extend([
            "-vVars",
            vvars
        ])
    ret = V3dLmerOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz"),
        residuals_file=execution.output_file(resid + ".nii.gz") if (resid is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLmerOutputs",
    "V_3D_LMER_METADATA",
    "v_3d_lmer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GCA_APPLY_METADATA = Metadata(
    id="004863971f906d9a0b7892c9101381a0f012a5c2.boutiques",
    name="gca-apply",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GcaApplyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gca_apply(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_lta: OutputPathType | None
    """Output LTA file"""
    output_m3z: OutputPathType | None
    """Output M3Z file"""
    normalized_gca: OutputPathType | None
    """Normalized GCA base MGZ file"""
    segmented_gca: OutputPathType | None
    """Segmented GCA base MGZ file"""
    stats_output: OutputPathType | None
    """Statistical output file"""


def gca_apply(
    gcafile: InputPathType,
    subject: str,
    nthreads: float | None = None,
    base: str | None = None,
    no_segstats: bool = False,
    subjects_dir: str | None = None,
    dice_seg: str | None = None,
    dice_file: str | None = None,
    lta: InputPathType | None = None,
    norm: InputPathType | None = None,
    input_mgz: InputPathType | None = None,
    brainmask: InputPathType | None = None,
    output_dir: str | None = None,
    no_v6labopts: bool = False,
    m3z_file: InputPathType | None = None,
    gca_rb_2016: bool = False,
    force_update: bool = False,
    gcareg_iters: float | None = None,
    runner: Runner | None = None,
) -> GcaApplyOutputs:
    """
    Applies a GCA, performing the steps of mri_em_register, mri_ca_normalize,
    mri_ca_register, and mri_ca_label. This script replicates the stages in
    recon-all without overwriting files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gcafile: GCA file.
        subject: Subject.
        nthreads: Number of OMP threads.
        base: Use gcabase for naming output files (default is basename gcafile).
        no_segstats: Do not compute segstats.
        subjects_dir: Subjects directory.
        dice_seg: Specify dice coefficient computation parameters.
        dice_file: Specify dice coefficient computation file.
        lta: Use SrcLTA instead of running mri_em_register.
        norm: Use SrcNorm instead of running mri_ca_normalize.
        input_mgz: Input file, default is nu.mgz.
        brainmask: Brainmask file, default is brainmask.mgz.
        output_dir: Output directory (default: SUBJECTS_DIR/subject).
        no_v6labopts: Do not include v6 command line options.
        m3z_file: M3Z file.
        gca_rb_2016: Use RB_all_2016-05-10.vc700.gca.
        force_update: Force recreation of a file even if it is younger than its\
            parents.
        gcareg_iters: Set to 1, only for testing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GcaApplyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GCA_APPLY_METADATA)
    cargs = []
    cargs.extend([
        "-apply",
        "gca" + execution.input_file(gcafile)
    ])
    cargs.append(subject)
    if nthreads is not None:
        cargs.extend([
            "--nthreads",
            str(nthreads)
        ])
    if base is not None:
        cargs.extend([
            "--base",
            base
        ])
    if no_segstats:
        cargs.append("--no-segstats")
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if dice_seg is not None:
        cargs.extend([
            "--dice",
            dice_seg
        ])
    if dice_file is not None:
        cargs.append(dice_file)
    if lta is not None:
        cargs.extend([
            "--lta",
            execution.input_file(lta)
        ])
    if norm is not None:
        cargs.extend([
            "--norm",
            execution.input_file(norm)
        ])
    if input_mgz is not None:
        cargs.extend([
            "--input",
            execution.input_file(input_mgz)
        ])
    if brainmask is not None:
        cargs.extend([
            "--brainmask",
            execution.input_file(brainmask)
        ])
    if output_dir is not None:
        cargs.extend([
            "--o",
            output_dir
        ])
    if no_v6labopts:
        cargs.append("--no-v6labopts")
    if m3z_file is not None:
        cargs.extend([
            "--m3z",
            execution.input_file(m3z_file)
        ])
    if gca_rb_2016:
        cargs.append("--gca-rb-2016")
    if force_update:
        cargs.append("--force-update")
    if gcareg_iters is not None:
        cargs.extend([
            "--gcareg-iters",
            str(gcareg_iters)
        ])
    ret = GcaApplyOutputs(
        root=execution.output_file("."),
        output_lta=execution.output_file(base + ".lta") if (base is not None) else None,
        output_m3z=execution.output_file(base + ".m3z") if (base is not None) else None,
        normalized_gca=execution.output_file("norm." + base + ".mgz") if (base is not None) else None,
        segmented_gca=execution.output_file(base + ".aseg.mgz") if (base is not None) else None,
        stats_output=execution.output_file(base + ".stats") if (base is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GCA_APPLY_METADATA",
    "GcaApplyOutputs",
    "gca_apply",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FIX_FSSPHERE_METADATA = Metadata(
    id="b742177d5b0ebe3a73650e2f92bfe87238f0bcca.boutiques",
    name="@fix_FSsphere",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFixFssphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__fix_fssphere(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_surface: OutputPathType
    """Corrected surface"""


def v__fix_fssphere(
    spec_file: InputPathType,
    sphere_file: InputPathType,
    num_iterations: int | None = None,
    extent_lim: float | None = None,
    project_first: bool = False,
    keep_temp: bool = False,
    runner: Runner | None = None,
) -> VFixFssphereOutputs:
    """
    Tool for fixing errors in FreeSurfer spherical surfaces.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        spec_file: Spec file.
        sphere_file: SPHERE.asc is the sphere to be used.
        num_iterations: Number of local smoothing operations. Default is 3000.
        extent_lim: Extent, in mm, by which troubled sections are fattened.\
            Default is 6.
        project_first: Project to a sphere, before smoothing. Default is 0.
        keep_temp: Keep temporary files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFixFssphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FIX_FSSPHERE_METADATA)
    cargs = []
    cargs.append("@fix_FSsphere")
    cargs.extend([
        "-spec",
        execution.input_file(spec_file)
    ])
    cargs.extend([
        "-sphere",
        execution.input_file(sphere_file)
    ])
    if num_iterations is not None:
        cargs.extend([
            "-niter",
            str(num_iterations)
        ])
    if extent_lim is not None:
        cargs.extend([
            "-lim",
            str(extent_lim)
        ])
    if project_first:
        cargs.append("-project_first")
    if keep_temp:
        cargs.append("-keep_temp")
    ret = VFixFssphereOutputs(
        root=execution.output_file("."),
        corrected_surface=execution.output_file("[SPHERE]_fxd.asc"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFixFssphereOutputs",
    "V__FIX_FSSPHERE_METADATA",
    "v__fix_fssphere",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_APPLY_AFFINE_METADATA = Metadata(
    id="25500b134b89cab81e66e3d0a44f8ea90dc1d25a.boutiques",
    name="surface-apply-affine",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class SurfaceApplyAffineFlirt:
    """
    MUST be used if affine is a flirt affine.
    """
    source_volume: str
    """the source volume used when generating the affine"""
    target_volume: str
    """the target volume used when generating the affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-flirt")
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


class SurfaceApplyAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_apply_affine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surf: OutputPathType
    """the output transformed surface"""


def surface_apply_affine(
    in_surf: InputPathType,
    affine: str,
    out_surf: str,
    flirt: SurfaceApplyAffineFlirt | None = None,
    runner: Runner | None = None,
) -> SurfaceApplyAffineOutputs:
    """
    Apply affine transform to surface file.
    
    For flirt matrices, you must use the -flirt option, because flirt matrices
    are not a complete description of the coordinate transform they represent.
    If the -flirt option is not present, the affine must be a nifti 'world'
    affine, which can be obtained with the -convert-affine command, or aff_conv
    from the 4dfp suite.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        in_surf: the surface to transform.
        affine: the affine file.
        out_surf: the output transformed surface.
        flirt: MUST be used if affine is a flirt affine.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceApplyAffineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_APPLY_AFFINE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-apply-affine")
    cargs.append(execution.input_file(in_surf))
    cargs.append(affine)
    cargs.append(out_surf)
    if flirt is not None:
        cargs.extend(flirt.run(execution))
    ret = SurfaceApplyAffineOutputs(
        root=execution.output_file("."),
        out_surf=execution.output_file(out_surf),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_APPLY_AFFINE_METADATA",
    "SurfaceApplyAffineFlirt",
    "SurfaceApplyAffineOutputs",
    "surface_apply_affine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_STRIP_SUBJECT_INFO_METADATA = Metadata(
    id="7f018807cf37f338df19c441f6450439090921fb.boutiques",
    name="mri_strip_subject_info",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriStripSubjectInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_strip_subject_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_strip_subject_info(
    input_files: list[InputPathType],
    output_directory: str,
    runner: Runner | None = None,
) -> MriStripSubjectInfoOutputs:
    """
    A tool to strip subject information from MRI data files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input file(s) containing MRI data.
        output_directory: Directory where stripped files will be saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriStripSubjectInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_STRIP_SUBJECT_INFO_METADATA)
    cargs = []
    cargs.append("mri_strip_subject_info")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append(output_directory)
    ret = MriStripSubjectInfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_STRIP_SUBJECT_INFO_METADATA",
    "MriStripSubjectInfoOutputs",
    "mri_strip_subject_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_4SWAP_METADATA = Metadata(
    id="b931a726528adf5a726f46c604f9851351673fb9.boutiques",
    name="4swap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V4swapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_4swap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_4swap(
    files: list[InputPathType],
    quiet: bool = False,
    runner: Runner | None = None,
) -> V4swapOutputs:
    """
    Swaps byte quadruples on the listed files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        files: List of files to process.
        quiet: Work quietly; suppress output messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V4swapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_4SWAP_METADATA)
    cargs = []
    cargs.append("4swap")
    cargs.extend([execution.input_file(f) for f in files])
    if quiet:
        cargs.append("-q")
    ret = V4swapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V4swapOutputs",
    "V_4SWAP_METADATA",
    "v_4swap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_PAR2_AFNI_METADATA = Metadata(
    id="955afce507c339e4fbf43caaf056ad39a659f439.boutiques",
    name="3dPAR2AFNI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dPar2AfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_par2_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Converted output files"""


def v_3d_par2_afni(
    input_file: InputPathType,
    skip_outliers_test: bool = False,
    output_analyze: bool = False,
    output_dir: str | None = None,
    verbose_flag: bool = False,
    gzip_files: bool = False,
    byte_swap_4: bool = False,
    runner: Runner | None = None,
) -> V3dPar2AfniOutputs:
    """
    Convert Philips PAR/REC files to AFNI's BRIK/HEAD, NIfTI, or ANALYZE format.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input PAR file (e.g., subject1.PAR).
        skip_outliers_test: Skip the outliers test when converting 4D files.\
            The default is to perform the outliers test.
        output_analyze: Output ANALYZE files instead of HEAD/BRIK.
        output_dir: The name of the directory where the created files should be\
            placed. If this directory does not exist, the program exits without\
            performing any conversion.
        verbose_flag: Be verbose in operation.
        gzip_files: Gzip the files created. The default is not to gzip the\
            files.
        byte_swap_4: 4-Byte-swap the files created. The default is not to 4\
            byte-swap.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dPar2AfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_PAR2_AFNI_METADATA)
    cargs = []
    cargs.append("3dPAR2AFNI.pl")
    cargs.append(execution.input_file(input_file))
    if skip_outliers_test:
        cargs.append("-s")
    if output_analyze:
        cargs.append("-a")
    if output_dir is not None:
        cargs.extend([
            "-o",
            output_dir
        ])
    if verbose_flag:
        cargs.append("-v")
    if gzip_files:
        cargs.append("-g")
    if byte_swap_4:
        cargs.append("-4")
    ret = V3dPar2AfniOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(pathlib.Path(input_file).name + "_converted"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dPar2AfniOutputs",
    "V_3D_PAR2_AFNI_METADATA",
    "v_3d_par2_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RCA_CONFIG2CSH_METADATA = Metadata(
    id="a6974f7a84f9b447ffa3652155f3daff457ba308.boutiques",
    name="rca-config2csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RcaConfig2cshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rca_config2csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rca_config2csh(
    configfile: InputPathType,
    runner: Runner | None = None,
) -> RcaConfig2cshOutputs:
    """
    rca-config2csh is a utility to convert configuration files into C-shell syntax.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        configfile: Configuration file to be converted.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RcaConfig2cshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RCA_CONFIG2CSH_METADATA)
    cargs = []
    cargs.extend([
        "-config2csh",
        "rca" + execution.input_file(configfile)
    ])
    ret = RcaConfig2cshOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RCA_CONFIG2CSH_METADATA",
    "RcaConfig2cshOutputs",
    "rca_config2csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RECONBATCHJOBS_METADATA = Metadata(
    id="3b88343e632e9bbafdf43ea3df14e2cf0c3f34d1.boutiques",
    name="reconbatchjobs",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReconbatchjobsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reconbatchjobs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def reconbatchjobs(
    logfile: str,
    cmdfiles: list[str],
    runner: Runner | None = None,
) -> ReconbatchjobsOutputs:
    """
    Batch job processor for reconstruction scripts.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        logfile: Log file to capture output of batch jobs.
        cmdfiles: Command files for batch processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReconbatchjobsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RECONBATCHJOBS_METADATA)
    cargs = []
    cargs.append("reconbatchjobs")
    cargs.append(logfile)
    cargs.extend(cmdfiles)
    ret = ReconbatchjobsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RECONBATCHJOBS_METADATA",
    "ReconbatchjobsOutputs",
    "reconbatchjobs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIND_VARIANCE_LINES_METADATA = Metadata(
    id="400a7e1ff61116676091a1736a0b5ffb08f0a496.boutiques",
    name="find_variance_lines",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FindVarianceLinesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `find_variance_lines(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    variance_maps: OutputPathType | None
    """Variance maps per run"""
    scaled_variance_maps: OutputPathType | None
    """Scaled variance maps per run"""
    cluster_reports: OutputPathType | None
    """Cluster reports"""
    jpeg_images: OutputPathType | None
    """JPEG images showing locations of high variance"""


def find_variance_lines(
    input_files: list[InputPathType],
    mask: str | None = None,
    min_cvox: int | None = None,
    min_nt: int | None = None,
    nerode: int | None = None,
    nfirst: int | None = None,
    percentile: int | None = None,
    polort: str | None = None,
    output_dir: str | None = None,
    do_clean: int | None = None,
    do_img: int | None = None,
    echo: bool = False,
    help_: bool = False,
    hist: bool = False,
    ver: bool = False,
    runner: Runner | None = None,
) -> FindVarianceLinesOutputs:
    """
    Look for bars of high variance that might suggest scanner interference in EPI
    datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input EPI datasets.
        mask: Mask for computations (default=AUTO).
        min_cvox: Minimum voxels for valid mask column (default=5).
        min_nt: Minimum number of time points required (default=10).
        nerode: How much to erode input or auto-mask (default=0).
        nfirst: Discard the first VAL time points (default=0).
        percentile: Percentile of variance values to scale to (default=90).
        polort: Polynomial detrending degree (default=A).
        output_dir: Name of the output directory (default=vlines.result).
        do_clean: Do we clean up a little? (default=1).
        do_img: Make vline images? (default=1).
        echo: Run script with shell 'echo' set (default=no).
        help_: Show this help.
        hist: Show the version history.
        ver: Show the current version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FindVarianceLinesOutputs`).
    """
    if percentile is not None and not (0 <= percentile <= 99): 
        raise ValueError(f"'percentile' must be between 0 <= x <= 99 but was {percentile}")
    if do_clean is not None and not (0 <= do_clean <= 1): 
        raise ValueError(f"'do_clean' must be between 0 <= x <= 1 but was {do_clean}")
    if do_img is not None and not (0 <= do_img <= 1): 
        raise ValueError(f"'do_img' must be between 0 <= x <= 1 but was {do_img}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIND_VARIANCE_LINES_METADATA)
    cargs = []
    cargs.append("find_variance_lines.tcsh")
    cargs.extend([execution.input_file(f) for f in input_files])
    if mask is not None:
        cargs.extend([
            "-mask",
            mask
        ])
    if min_cvox is not None:
        cargs.extend([
            "-min_cvox",
            str(min_cvox)
        ])
    if min_nt is not None:
        cargs.extend([
            "-min_nt",
            str(min_nt)
        ])
    if nerode is not None:
        cargs.extend([
            "-nerode",
            str(nerode)
        ])
    if nfirst is not None:
        cargs.extend([
            "-nfirst",
            str(nfirst)
        ])
    if percentile is not None:
        cargs.extend([
            "-perc",
            str(percentile)
        ])
    if polort is not None:
        cargs.extend([
            "-polort",
            polort
        ])
    if output_dir is not None:
        cargs.extend([
            "-rdir",
            output_dir
        ])
    if do_clean is not None:
        cargs.extend([
            "-do_clean",
            str(do_clean)
        ])
    if do_img is not None:
        cargs.extend([
            "-do_img",
            str(do_img)
        ])
    if echo:
        cargs.append("-echo")
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if ver:
        cargs.append("-ver")
    ret = FindVarianceLinesOutputs(
        root=execution.output_file("."),
        variance_maps=execution.output_file(output_dir + "/variance_map_run*.nii.gz") if (output_dir is not None) else None,
        scaled_variance_maps=execution.output_file(output_dir + "/scaled_variance_map_run*.nii.gz") if (output_dir is not None) else None,
        cluster_reports=execution.output_file(output_dir + "/cluster_report_run*.txt") if (output_dir is not None) else None,
        jpeg_images=execution.output_file(output_dir + "/*.jpg") if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIND_VARIANCE_LINES_METADATA",
    "FindVarianceLinesOutputs",
    "find_variance_lines",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FAT_TRACT_COLORIZE_METADATA = Metadata(
    id="08df2223341e8a3953edfe06cc72302451f3e2c8.boutiques",
    name="@fat_tract_colorize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFatTractColorizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__fat_tract_colorize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_hue_volume: OutputPathType
    """HSL coloration volume file with four bricks from the V1 and FA volumes:
    Hue, Saturation, Luminosity, and Brightness"""
    output_iso_surface: OutputPathType
    """Slightly smoothed isosurface file made by IsoSurface"""
    output_iso_spec: OutputPathType
    """Spec file made by quickspec"""
    output_proj_surface: OutputPathType
    """Projection of appropriate coloration onto the surface"""


def v__fat_tract_colorize(
    in_fa: InputPathType,
    in_v1: InputPathType,
    in_tracts: str,
    prefix: str,
    in_ulay: InputPathType | None = None,
    no_view: bool = False,
    only_view: bool = False,
    runner: Runner | None = None,
) -> VFatTractColorizeOutputs:
    """
    Visualize tractographic output from 3dTrackID, particularly in probabilistic
    mode.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_fa: FA values of the DT fitting, used to modulate the brightness of\
            the RGB coloration.
        in_v1: First eigenvector of the DT fitting. A unit vector volume with 3\
            components (0-1 range).
        in_tracts: The INDIMAP or PAIRMAP file output by 3dTrackID, specifying\
            the subbrick if >1 (e.g., NAME_INDIMAP+orig'[0]').
        prefix: Prefix for all output files.
        in_ulay: Optional underlay dataset for AFNI/SUMA viewing. Default is to\
            use the FA dataset.
        no_view: Turn off auto-running of AFNI_SUMA commands to view the output\
            immediately.
        only_view: Only view the data with AFNI+SUMA, assuming the command has\
            been run before.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFatTractColorizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FAT_TRACT_COLORIZE_METADATA)
    cargs = []
    cargs.append("@fat_tract_colorize")
    cargs.extend([
        "-in_fa",
        execution.input_file(in_fa)
    ])
    cargs.extend([
        "-in_v1",
        execution.input_file(in_v1)
    ])
    cargs.extend([
        "-in_tracts",
        in_tracts
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if in_ulay is not None:
        cargs.extend([
            "-in_ulay",
            execution.input_file(in_ulay)
        ])
    if no_view:
        cargs.append("-no_view")
    if only_view:
        cargs.append("-only_view")
    ret = VFatTractColorizeOutputs(
        root=execution.output_file("."),
        output_hue_volume=execution.output_file(prefix + "_RGB_HUE.nii.gz"),
        output_iso_surface=execution.output_file(prefix + "_RGB_iso.ply"),
        output_iso_spec=execution.output_file(prefix + "_RGB_iso.spec"),
        output_proj_surface=execution.output_file(prefix + "_RGB.niml.dset"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFatTractColorizeOutputs",
    "V__FAT_TRACT_COLORIZE_METADATA",
    "v__fat_tract_colorize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AVSCALE_METADATA = Metadata(
    id="55dd77b83020d0048dbe4f542385e6f483818b7c.boutiques",
    name="avscale",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class AvscaleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `avscale(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The output file."""


def avscale(
    matrix_file: InputPathType,
    allparams_flag: bool = False,
    inverteddies_flag: bool = False,
    non_reference_volume: InputPathType | None = None,
    runner: Runner | None = None,
) -> AvscaleOutputs:
    """
    A command line tool for computing affine transformations.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        matrix_file: The path to the matrix file.
        allparams_flag: Flag for all parameters.
        inverteddies_flag: Flag for inverted eddies.
        non_reference_volume: The path to the non-reference volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AvscaleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AVSCALE_METADATA)
    cargs = []
    cargs.append("avscale")
    if allparams_flag:
        cargs.append("--allparams")
    if inverteddies_flag:
        cargs.append("--inverteddies")
    cargs.append(execution.input_file(matrix_file))
    if non_reference_volume is not None:
        cargs.append(execution.input_file(non_reference_volume))
    cargs.append(">")
    cargs.append("output.txt")
    ret = AvscaleOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AVSCALE_METADATA",
    "AvscaleOutputs",
    "avscale",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SAMPLE_LABEL_METADATA = Metadata(
    id="c932dc0a98511082cdc147b0bac256709172f10e.boutiques",
    name="mris_sample_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSampleLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_sample_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label_file: OutputPathType
    """The resulting output label file"""


def mris_sample_label(
    input_label_file: InputPathType,
    input_surface_file: InputPathType,
    output_label_file: str,
    runner: Runner | None = None,
) -> MrisSampleLabelOutputs:
    """
    This tool samples a label onto a surface model.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_label_file: Input label file.
        input_surface_file: Input surface file.
        output_label_file: Output label file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSampleLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SAMPLE_LABEL_METADATA)
    cargs = []
    cargs.append("mris_sample_label")
    cargs.append(execution.input_file(input_label_file))
    cargs.append(execution.input_file(input_surface_file))
    cargs.append(output_label_file)
    ret = MrisSampleLabelOutputs(
        root=execution.output_file("."),
        output_label_file=execution.output_file(output_label_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SAMPLE_LABEL_METADATA",
    "MrisSampleLabelOutputs",
    "mris_sample_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_ALIGN_ANAT_PAIR_METADATA = Metadata(
    id="b81d41214e66c7f77b2bbc885c2f23369ad68254.boutiques",
    name="fat_proc_align_anat_pair",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcAlignAnatPairOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_align_anat_pair(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_t1w: OutputPathType
    """Aligned T1w volume"""
    qc_snapshot_t1w_on_t2w: OutputPathType
    """QC snapshot of the T1w volume overlaying the T2w volume"""
    qc_snapshot_t1w_edges_on_t2w: OutputPathType
    """QC snapshot of the T1w edges overlaying the T2w volume"""


def fat_proc_align_anat_pair(
    input_t1w: InputPathType,
    input_t2w: InputPathType,
    output_prefix: str,
    output_grid: float | None = None,
    input_t2w_mask: InputPathType | None = None,
    do_ss_tmp_t1w: bool = False,
    warp: str | None = None,
    matrix: InputPathType | None = None,
    workdir: str | None = None,
    no_cmd_out: bool = False,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> FatProcAlignAnatPairOutputs:
    """
    A tool for aligning a T1w anatomical image to a T2w anatomical image using
    solid-body parameters (translation and rotation).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_t1w: T1-weighted volume.
        input_t2w: T2-weighted volume.
        output_prefix: Output prefix for files and snapshots.
        output_grid: Specify output T1w volume's final resolution (isotropic).
        input_t2w_mask: Input a mask to apply to the T2w volume for alignment.
        do_ss_tmp_t1w: Apply skullstripping to the T1w volume during an\
            intermediate step.
        warp: Specify the degrees of freedom for warping using options from\
            3dAllineate.
        matrix: Apply a pre-made matrix from 3dAllineate.
        workdir: Specify a working directory.
        no_cmd_out: Do not save the command line call and the location where it\
            was run.
        no_clean: Do not delete the temporary working directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcAlignAnatPairOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_ALIGN_ANAT_PAIR_METADATA)
    cargs = []
    cargs.append("fat_proc_align_anat_pair")
    cargs.extend([
        "-in_t1w",
        execution.input_file(input_t1w)
    ])
    cargs.extend([
        "-in_t2w",
        execution.input_file(input_t2w)
    ])
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if output_grid is not None:
        cargs.extend([
            "-newgrid",
            str(output_grid)
        ])
    if input_t2w_mask is not None:
        cargs.extend([
            "-in_t2w_mask",
            execution.input_file(input_t2w_mask)
        ])
    if do_ss_tmp_t1w:
        cargs.append("-do_ss_tmp_t1w")
    if warp is not None:
        cargs.extend([
            "-warp",
            warp
        ])
    if matrix is not None:
        cargs.extend([
            "-matrix",
            execution.input_file(matrix)
        ])
    if workdir is not None:
        cargs.extend([
            "-workdir",
            workdir
        ])
    if no_cmd_out:
        cargs.append("-no_cmd_out")
    if no_clean:
        cargs.append("-no_clean")
    ret = FatProcAlignAnatPairOutputs(
        root=execution.output_file("."),
        aligned_t1w=execution.output_file(output_prefix + "_t1w_aligned.nii.gz"),
        qc_snapshot_t1w_on_t2w=execution.output_file(output_prefix + "_QC_T1w_over_T2w.png"),
        qc_snapshot_t1w_edges_on_t2w=execution.output_file(output_prefix + "_QC_T1w_edges_over_T2w.png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_ALIGN_ANAT_PAIR_METADATA",
    "FatProcAlignAnatPairOutputs",
    "fat_proc_align_anat_pair",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DICE_METRIC_METADATA = Metadata(
    id="98eaa1a4d4837bef42b0135a72612d83719e6632.boutiques",
    name="@DiceMetric",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDiceMetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__dice_metric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__dice_metric(
    base: InputPathType,
    dsets: list[InputPathType],
    max_roi: float | None = None,
    forceoutput: InputPathType | None = None,
    forceoutput_: InputPathType | None = None,
    echo: bool = False,
    save_match: bool = False,
    save_diff: bool = False,
    do_not_mask_by_base: bool = False,
    mask_by_base: bool = False,
    prefix: str | None = None,
    ignore_bad: bool = False,
    keep_tmp: bool = False,
    runner: Runner | None = None,
) -> VDiceMetricOutputs:
    """
    Computes Dice Metric between BASE and each of the DSET volumes.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        base: Name of base (reference) segmentation.
        dsets: Data sets for which the Dice Metric with BASE is computed. This\
            should be the last option on the command line.
        max_roi: The maximum possible ROI index. Default is 12 or based on\
            LTFILE if specified.
        forceoutput: If given, force output for each class in LTFILE.
        forceoutput_: If given, force output for each class in LTFILE.
        echo: Set echo.
        save_match: Save volume showing BASE*equals(BASE,DSET).
        save_diff: Save volume showing BASE*(1-equals(BASE,DSET)).
        do_not_mask_by_base: Do not mask dset by step(base) before computing\
            Dice coefficient.
        mask_by_base: Mask dset by the step(base) before computing Dice\
            coefficient.
        prefix: Use PREFIX for the output table. Default is separate results\
            for each dset to stdout.
        ignore_bad: Warn if encountering bad scenarios, but do not create a\
            zero entry.
        keep_tmp: Keep temporary files for debugging. Note that you should\
            delete temporary files before rerunning the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDiceMetricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DICE_METRIC_METADATA)
    cargs = []
    cargs.append("@DiceMetric")
    cargs.extend([
        "-base",
        execution.input_file(base)
    ])
    cargs.extend([
        "-dsets",
        *[execution.input_file(f) for f in dsets]
    ])
    if max_roi is not None:
        cargs.extend([
            "-max_N_roi",
            str(max_roi)
        ])
    if forceoutput is not None:
        cargs.extend([
            "-forceoutput",
            execution.input_file(forceoutput)
        ])
    if forceoutput_ is not None:
        cargs.extend([
            "-forceoutput",
            execution.input_file(forceoutput_)
        ])
    if echo:
        cargs.append("-echo")
    if save_match:
        cargs.append("-save_match")
    if save_diff:
        cargs.append("-save_diff")
    if do_not_mask_by_base:
        cargs.append("-do_not_mask_by_base")
    if mask_by_base:
        cargs.append("-mask_by_base")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if ignore_bad:
        cargs.append("-ignore_bad")
    if keep_tmp:
        cargs.append("-keep_tmp")
    ret = VDiceMetricOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDiceMetricOutputs",
    "V__DICE_METRIC_METADATA",
    "v__dice_metric",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL2PATCH_METADATA = Metadata(
    id="8785c2dbe1c1b6e295f643297a4b281d53553dd6.boutiques",
    name="label2patch",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Label2patchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label2patch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def label2patch(
    subject_name: str,
    hemisphere: str,
    label_file: InputPathType,
    output_patch: str,
    dilate: float | None = None,
    erode: float | None = None,
    close: float | None = None,
    subjects_dir: str | None = None,
    surface_name: str | None = None,
    write_surface: bool = False,
    runner: Runner | None = None,
) -> Label2patchOutputs:
    """
    Utility to create patches from label files in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name.
        hemisphere: Hemisphere (e.g. lh or rh).
        label_file: Label file name.
        output_patch: Output patch file.
        dilate: Dilate the label n times before creating the patch.
        erode: Erode the label n times before creating the patch.
        close: Close the label n times before creating the patch.
        subjects_dir: Use path as the SUBJECTS_DIR instead of environment.
        surface_name: Use name as the surface (default 'inflated').
        write_surface: Write output to a surface file (not a patch). Use .stl\
            in filename to only write the mesh covered by the label, saving it in\
            FS format will save full surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Label2patchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL2PATCH_METADATA)
    cargs = []
    cargs.append("label2patch")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    cargs.append(execution.input_file(label_file))
    cargs.append(output_patch)
    if dilate is not None:
        cargs.extend([
            "-dilate",
            str(dilate)
        ])
    if erode is not None:
        cargs.extend([
            "-erode",
            str(erode)
        ])
    if close is not None:
        cargs.extend([
            "-close",
            str(close)
        ])
    if subjects_dir is not None:
        cargs.extend([
            "-sdir",
            subjects_dir
        ])
    if surface_name is not None:
        cargs.extend([
            "-surf",
            surface_name
        ])
    if write_surface:
        cargs.append("-writesurf")
    ret = Label2patchOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL2PATCH_METADATA",
    "Label2patchOutputs",
    "label2patch",
]
